Implements the "Residual (Sur)Realism" algorithm described by Stefanski (2007) tools:::Rd_expr_doi("10.1198/000313007X190079") to generate datasets that reveal hidden images or messages in their residual plots. It offers both predefined datasets and tools to embed custom text or images into residual structures. Allowing users to create intriguing visual demonstrations for teaching model diagnostics.
Maintainer: James Joseph Balamuta james.balamuta@gmail.com (ORCID) [copyright holder]